summaryrefslogtreecommitdiffstats
path: root/chrome/browser/bookmarks
diff options
context:
space:
mode:
authortfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-11-26 23:12:49 +0000
committertfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-11-26 23:12:49 +0000
commitdd059852a027d4850bc68dc1e6f2ecdb300cfa8e (patch)
tree8493d5442f2c4676e7c8753e367638f68ba9fd7a /chrome/browser/bookmarks
parent398d24f2ee4e9b5bdb8a66751c1c8ca95c268843 (diff)
downloadchromium_src-dd059852a027d4850bc68dc1e6f2ecdb300cfa8e.zip
chromium_src-dd059852a027d4850bc68dc1e6f2ecdb300cfa8e.tar.gz
chromium_src-dd059852a027d4850bc68dc1e6f2ecdb300cfa8e.tar.bz2
Rename BookmarkDragData to BookmarkNodeData. Part 2.
BUG=37891 TEST=trybots Review URL: http://codereview.chromium.org/5249001 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@67477 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/bookmarks')
-rw-r--r--chrome/browser/bookmarks/bookmark_drag_data.cc64
-rw-r--r--chrome/browser/bookmarks/bookmark_drag_data.h38
-rw-r--r--chrome/browser/bookmarks/bookmark_drag_data_unittest.cc54
-rw-r--r--chrome/browser/bookmarks/bookmark_drop_info.h2
-rw-r--r--chrome/browser/bookmarks/bookmark_pasteboard_helper_mac.h2
-rw-r--r--chrome/browser/bookmarks/bookmark_utils.cc2
-rw-r--r--chrome/browser/bookmarks/bookmark_utils.h2
7 files changed, 78 insertions, 86 deletions
diff --git a/chrome/browser/bookmarks/bookmark_drag_data.cc b/chrome/browser/bookmarks/bookmark_drag_data.cc
index 44ab58e..a31f7aa 100644
--- a/chrome/browser/bookmarks/bookmark_drag_data.cc
+++ b/chrome/browser/bookmarks/bookmark_drag_data.cc
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#include "chrome/browser/bookmarks/bookmark_drag_data.h"
+#include "chrome/browser/bookmarks/bookmark_node_data.h"
#include "app/clipboard/scoped_clipboard_writer.h"
#include "base/basictypes.h"
@@ -18,13 +18,13 @@
#include "chrome/browser/browser_process.h"
#include "net/base/escape.h"
-const char* BookmarkDragData::kClipboardFormatString =
+const char* BookmarkNodeData::kClipboardFormatString =
"chromium/x-bookmark-entries";
-BookmarkDragData::Element::Element() : is_url(false), id_(0) {
+BookmarkNodeData::Element::Element() : is_url(false), id_(0) {
}
-BookmarkDragData::Element::Element(const BookmarkNode* node)
+BookmarkNodeData::Element::Element(const BookmarkNode* node)
: is_url(node->is_url()),
url(node->GetURL()),
title(node->GetTitle()),
@@ -33,10 +33,10 @@ BookmarkDragData::Element::Element(const BookmarkNode* node)
children.push_back(Element(node->GetChild(i)));
}
-BookmarkDragData::Element::~Element() {
+BookmarkNodeData::Element::~Element() {
}
-void BookmarkDragData::Element::WriteToPickle(Pickle* pickle) const {
+void BookmarkNodeData::Element::WriteToPickle(Pickle* pickle) const {
pickle->WriteBool(is_url);
pickle->WriteString(url.spec());
pickle->WriteString16(title);
@@ -50,7 +50,7 @@ void BookmarkDragData::Element::WriteToPickle(Pickle* pickle) const {
}
}
-bool BookmarkDragData::Element::ReadFromPickle(Pickle* pickle,
+bool BookmarkNodeData::Element::ReadFromPickle(Pickle* pickle,
void** iterator) {
std::string url_spec;
if (!pickle->ReadBool(iterator, &is_url) ||
@@ -77,35 +77,35 @@ bool BookmarkDragData::Element::ReadFromPickle(Pickle* pickle,
#if defined(TOOLKIT_VIEWS)
// static
-OSExchangeData::CustomFormat BookmarkDragData::GetBookmarkCustomFormat() {
+OSExchangeData::CustomFormat BookmarkNodeData::GetBookmarkCustomFormat() {
static OSExchangeData::CustomFormat format;
static bool format_valid = false;
if (!format_valid) {
format_valid = true;
format = OSExchangeData::RegisterCustomFormat(
- BookmarkDragData::kClipboardFormatString);
+ BookmarkNodeData::kClipboardFormatString);
}
return format;
}
#endif
-BookmarkDragData::BookmarkDragData() {
+BookmarkNodeData::BookmarkNodeData() {
}
-BookmarkDragData::BookmarkDragData(const BookmarkNode* node) {
+BookmarkNodeData::BookmarkNodeData(const BookmarkNode* node) {
elements.push_back(Element(node));
}
-BookmarkDragData::BookmarkDragData(
+BookmarkNodeData::BookmarkNodeData(
const std::vector<const BookmarkNode*>& nodes) {
ReadFromVector(nodes);
}
-BookmarkDragData::~BookmarkDragData() {
+BookmarkNodeData::~BookmarkNodeData() {
}
-bool BookmarkDragData::ReadFromVector(
+bool BookmarkNodeData::ReadFromVector(
const std::vector<const BookmarkNode*>& nodes) {
Clear();
@@ -118,7 +118,7 @@ bool BookmarkDragData::ReadFromVector(
return true;
}
-bool BookmarkDragData::ReadFromTuple(const GURL& url, const string16& title) {
+bool BookmarkNodeData::ReadFromTuple(const GURL& url, const string16& title) {
Clear();
if (!url.is_valid())
@@ -135,7 +135,7 @@ bool BookmarkDragData::ReadFromTuple(const GURL& url, const string16& title) {
}
#if !defined(OS_MACOSX)
-void BookmarkDragData::WriteToClipboard(Profile* profile) const {
+void BookmarkNodeData::WriteToClipboard(Profile* profile) const {
ScopedClipboardWriter scw(g_browser_process->clipboard());
// If there is only one element and it is a URL, write the URL to the
@@ -160,7 +160,7 @@ void BookmarkDragData::WriteToClipboard(Profile* profile) const {
scw.WritePickledData(pickle, kClipboardFormatString);
}
-bool BookmarkDragData::ReadFromClipboard() {
+bool BookmarkNodeData::ReadFromClipboard() {
std::string data;
Clipboard* clipboard = g_browser_process->clipboard();
clipboard->ReadData(kClipboardFormatString, &data);
@@ -188,32 +188,32 @@ bool BookmarkDragData::ReadFromClipboard() {
return false;
}
-bool BookmarkDragData::ClipboardContainsBookmarks() {
+bool BookmarkNodeData::ClipboardContainsBookmarks() {
return g_browser_process->clipboard()->IsFormatAvailableByString(
- BookmarkDragData::kClipboardFormatString, Clipboard::BUFFER_STANDARD);
+ BookmarkNodeData::kClipboardFormatString, Clipboard::BUFFER_STANDARD);
}
#else
-void BookmarkDragData::WriteToClipboard(Profile* profile) const {
+void BookmarkNodeData::WriteToClipboard(Profile* profile) const {
bookmark_pasteboard_helper_mac::WriteToClipboard(elements, profile_path_);
}
-bool BookmarkDragData::ReadFromClipboard() {
+bool BookmarkNodeData::ReadFromClipboard() {
return bookmark_pasteboard_helper_mac::ReadFromClipboard(elements,
&profile_path_);
}
-bool BookmarkDragData::ReadFromDragClipboard() {
+bool BookmarkNodeData::ReadFromDragClipboard() {
return bookmark_pasteboard_helper_mac::ReadFromDragClipboard(elements,
&profile_path_);
}
-bool BookmarkDragData::ClipboardContainsBookmarks() {
+bool BookmarkNodeData::ClipboardContainsBookmarks() {
return bookmark_pasteboard_helper_mac::ClipboardContainsBookmarks();
}
#endif // !defined(OS_MACOSX)
#if defined(TOOLKIT_VIEWS)
-void BookmarkDragData::Write(Profile* profile, OSExchangeData* data) const {
+void BookmarkNodeData::Write(Profile* profile, OSExchangeData* data) const {
DCHECK(data);
// If there is only one element and it is a URL, write the URL to the
@@ -232,7 +232,7 @@ void BookmarkDragData::Write(Profile* profile, OSExchangeData* data) const {
data->SetPickledData(GetBookmarkCustomFormat(), data_pickle);
}
-bool BookmarkDragData::Read(const OSExchangeData& data) {
+bool BookmarkNodeData::Read(const OSExchangeData& data) {
elements.clear();
profile_path_.clear();
@@ -256,7 +256,7 @@ bool BookmarkDragData::Read(const OSExchangeData& data) {
}
#endif
-void BookmarkDragData::WriteToPickle(Profile* profile, Pickle* pickle) const {
+void BookmarkNodeData::WriteToPickle(Profile* profile, Pickle* pickle) const {
FilePath path = profile ? profile->GetPath() : FilePath();
FilePath::WriteStringTypeToPickle(pickle, path.value());
pickle->WriteSize(elements.size());
@@ -265,7 +265,7 @@ void BookmarkDragData::WriteToPickle(Profile* profile, Pickle* pickle) const {
elements[i].WriteToPickle(pickle);
}
-bool BookmarkDragData::ReadFromPickle(Pickle* pickle) {
+bool BookmarkNodeData::ReadFromPickle(Pickle* pickle) {
void* data_iterator = NULL;
size_t element_count;
if (FilePath::ReadStringTypeFromPickle(pickle, &data_iterator,
@@ -284,7 +284,7 @@ bool BookmarkDragData::ReadFromPickle(Pickle* pickle) {
return true;
}
-std::vector<const BookmarkNode*> BookmarkDragData::GetNodes(
+std::vector<const BookmarkNode*> BookmarkNodeData::GetNodes(
Profile* profile) const {
std::vector<const BookmarkNode*> nodes;
@@ -303,24 +303,24 @@ std::vector<const BookmarkNode*> BookmarkDragData::GetNodes(
return nodes;
}
-const BookmarkNode* BookmarkDragData::GetFirstNode(Profile* profile) const {
+const BookmarkNode* BookmarkNodeData::GetFirstNode(Profile* profile) const {
std::vector<const BookmarkNode*> nodes = GetNodes(profile);
return nodes.size() == 1 ? nodes[0] : NULL;
}
-void BookmarkDragData::Clear() {
+void BookmarkNodeData::Clear() {
profile_path_.clear();
elements.clear();
}
-void BookmarkDragData::SetOriginatingProfile(Profile* profile) {
+void BookmarkNodeData::SetOriginatingProfile(Profile* profile) {
DCHECK(profile_path_.empty());
if (profile)
profile_path_ = profile->GetPath().value();
}
-bool BookmarkDragData::IsFromProfile(Profile* profile) const {
+bool BookmarkNodeData::IsFromProfile(Profile* profile) const {
// An empty path means the data is not associated with any profile.
return !profile_path_.empty() && profile_path_ == profile->GetPath().value();
}
diff --git a/chrome/browser/bookmarks/bookmark_drag_data.h b/chrome/browser/bookmarks/bookmark_drag_data.h
index 55c9c7b..8b8310d 100644
--- a/chrome/browser/bookmarks/bookmark_drag_data.h
+++ b/chrome/browser/bookmarks/bookmark_drag_data.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_BOOKMARKS_BOOKMARK_DRAG_DATA_H_
-#define CHROME_BROWSER_BOOKMARKS_BOOKMARK_DRAG_DATA_H_
+#ifndef CHROME_BROWSER_BOOKMARKS_BOOKMARK_NODE_DATA_H_
+#define CHROME_BROWSER_BOOKMARKS_BOOKMARK_NODE_DATA_H_
#pragma once
#include <vector>
@@ -20,28 +20,25 @@ class BookmarkNode;
class Pickle;
class Profile;
-// TODO(mrossetti): Rename BookmarkDragData to BookmarkNodeData, update comment.
-// See: http://crbug.com/37891
-
-// BookmarkDragData is used to represent the following:
+// BookmarkNodeData is used to represent the following:
//
// . A single URL.
// . A single node from the bookmark model.
// . A set of nodes from the bookmark model.
//
-// BookmarkDragData is used by bookmark related views to represent a dragged
+// BookmarkNodeData is used by bookmark related views to represent a dragged
// bookmark or bookmarks.
//
// Typical usage when writing data for a drag is:
-// BookmarkDragData data(node_user_is_dragging);
+// BookmarkNodeData data(node_user_is_dragging);
// data.Write(os_exchange_data_for_drag);
//
// Typical usage to read is:
-// BookmarkDragData data;
+// BookmarkNodeData data;
// if (data.Read(os_exchange_data))
// // data is valid, contents are in elements.
-struct BookmarkDragData {
+struct BookmarkNodeData {
// Element represents a single node.
struct Element {
Element();
@@ -64,7 +61,7 @@ struct BookmarkDragData {
return id_;
}
private:
- friend struct BookmarkDragData;
+ friend struct BookmarkNodeData;
// For reading/writing this Element.
void WriteToPickle(Pickle* pickle) const;
@@ -74,17 +71,17 @@ struct BookmarkDragData {
int64 id_;
};
- BookmarkDragData();
+ BookmarkNodeData();
#if defined(TOOLKIT_VIEWS)
static OSExchangeData::CustomFormat GetBookmarkCustomFormat();
#endif
- // Created a BookmarkDragData populated from the arguments.
- explicit BookmarkDragData(const BookmarkNode* node);
- explicit BookmarkDragData(const std::vector<const BookmarkNode*>& nodes);
+ // Created a BookmarkNodeData populated from the arguments.
+ explicit BookmarkNodeData(const BookmarkNode* node);
+ explicit BookmarkNodeData(const std::vector<const BookmarkNode*>& nodes);
- ~BookmarkDragData();
+ ~BookmarkNodeData();
// Reads bookmarks from the given vector.
bool ReadFromVector(const std::vector<const BookmarkNode*>& nodes);
@@ -156,7 +153,7 @@ struct BookmarkDragData {
// The actual elements written to the clipboard.
std::vector<Element> elements;
- // The MIME type for the clipboard format for BookmarkDragData.
+ // The MIME type for the clipboard format for BookmarkNodeData.
static const char* kClipboardFormatString;
static bool ClipboardContainsBookmarks();
@@ -166,9 +163,4 @@ struct BookmarkDragData {
FilePath::StringType profile_path_;
};
-// TODO(tfarina): Remove this when we finish renaming all the remaining entries.
-// This is a temporary hack, to make it possible to convert all the entries in
-// small chunks. See crbug.com/37891 for context.
-typedef BookmarkDragData BookmarkNodeData;
-
-#endif // CHROME_BROWSER_BOOKMARKS_BOOKMARK_DRAG_DATA_H_
+#endif // CHROME_BROWSER_BOOKMARKS_BOOKMARK_NODE_DATA_H_
diff --git a/chrome/browser/bookmarks/bookmark_drop_info.h b/chrome/browser/bookmarks/bookmark_drop_info.h
index c325244..1faea29 100644
--- a/chrome/browser/bookmarks/bookmark_drop_info.h
+++ b/chrome/browser/bookmarks/bookmark_drop_info.h
@@ -8,7 +8,7 @@
#include "base/basictypes.h"
#include "base/timer.h"
-#include "chrome/browser/bookmarks/bookmark_drag_data.h"
+#include "chrome/browser/bookmarks/bookmark_node_data.h"
#include "gfx/native_widget_types.h"
namespace views {
diff --git a/chrome/browser/bookmarks/bookmark_pasteboard_helper_mac.h b/chrome/browser/bookmarks/bookmark_pasteboard_helper_mac.h
index 6df2486..4ffc008 100644
--- a/chrome/browser/bookmarks/bookmark_pasteboard_helper_mac.h
+++ b/chrome/browser/bookmarks/bookmark_pasteboard_helper_mac.h
@@ -7,7 +7,7 @@
#pragma once
#include "base/file_path.h"
-#include "chrome/browser/bookmarks/bookmark_drag_data.h"
+#include "chrome/browser/bookmarks/bookmark_node_data.h"
#include "gfx/native_widget_types.h"
// This set of functions lets C++ code interact with the cocoa pasteboard
diff --git a/chrome/browser/bookmarks/bookmark_utils.cc b/chrome/browser/bookmarks/bookmark_utils.cc
index d93e3ed..fccbbb9 100644
--- a/chrome/browser/bookmarks/bookmark_utils.cc
+++ b/chrome/browser/bookmarks/bookmark_utils.cc
@@ -13,7 +13,7 @@
#include "base/string16.h"
#include "base/time.h"
#include "base/utf_string_conversions.h"
-#include "chrome/browser/bookmarks/bookmark_drag_data.h"
+#include "chrome/browser/bookmarks/bookmark_node_data.h"
#include "chrome/browser/bookmarks/bookmark_model.h"
#if defined(OS_MACOSX)
#include "chrome/browser/bookmarks/bookmark_pasteboard_helper_mac.h"
diff --git a/chrome/browser/bookmarks/bookmark_utils.h b/chrome/browser/bookmarks/bookmark_utils.h
index cab325f..0fc7615 100644
--- a/chrome/browser/bookmarks/bookmark_utils.h
+++ b/chrome/browser/bookmarks/bookmark_utils.h
@@ -10,7 +10,7 @@
#include <vector>
#include "base/string16.h"
-#include "chrome/browser/bookmarks/bookmark_drag_data.h"
+#include "chrome/browser/bookmarks/bookmark_node_data.h"
#include "chrome/browser/bookmarks/bookmark_editor.h"
#include "chrome/browser/history/snippet.h"
#include "gfx/native_widget_types.h"
diff --git a/chrome/browser/bookmarks/bookmark_drag_data_unittest.cc b/chrome/browser/bookmarks/bookmark_drag_data_unittest.cc
index 331a78a..a81d0a0 100644
--- a/chrome/browser/bookmarks/bookmark_drag_data_unittest.cc
+++ b/chrome/browser/bookmarks/bookmark_drag_data_unittest.cc
@@ -8,16 +8,16 @@
#include "base/scoped_ptr.h"
#include "base/string16.h"
#include "base/utf_string_conversions.h"
-#include "chrome/browser/bookmarks/bookmark_drag_data.h"
+#include "chrome/browser/bookmarks/bookmark_node_data.h"
#include "chrome/browser/bookmarks/bookmark_model.h"
#include "chrome/browser/browser_thread.h"
#include "chrome/test/testing_profile.h"
#include "googleurl/src/gurl.h"
#include "testing/gtest/include/gtest/gtest.h"
-class BookmarkDragDataTest : public testing::Test {
+class BookmarkNodeDataTest : public testing::Test {
public:
- BookmarkDragDataTest()
+ BookmarkNodeDataTest()
: ui_thread_(BrowserThread::UI, &loop_),
file_thread_(BrowserThread::FILE, &loop_) { }
@@ -36,30 +36,30 @@ OSExchangeData::Provider* CloneProvider(const OSExchangeData& data) {
} // namespace
-// Makes sure BookmarkDragData is initially invalid.
-TEST_F(BookmarkDragDataTest, InitialState) {
- BookmarkDragData data;
+// Makes sure BookmarkNodeData is initially invalid.
+TEST_F(BookmarkNodeDataTest, InitialState) {
+ BookmarkNodeData data;
EXPECT_FALSE(data.is_valid());
}
-// Makes sure reading bogus data leaves the BookmarkDragData invalid.
-TEST_F(BookmarkDragDataTest, BogusRead) {
+// Makes sure reading bogus data leaves the BookmarkNodeData invalid.
+TEST_F(BookmarkNodeDataTest, BogusRead) {
OSExchangeData data;
- BookmarkDragData drag_data;
+ BookmarkNodeData drag_data;
EXPECT_FALSE(drag_data.Read(OSExchangeData(CloneProvider(data))));
EXPECT_FALSE(drag_data.is_valid());
}
// Writes a URL to the clipboard and make sure BookmarkDragData can correctly
// read it.
-TEST_F(BookmarkDragDataTest, JustURL) {
+TEST_F(BookmarkNodeDataTest, JustURL) {
const GURL url("http://google.com");
const std::wstring title(L"title");
OSExchangeData data;
data.SetURL(url, title);
- BookmarkDragData drag_data;
+ BookmarkNodeData drag_data;
EXPECT_TRUE(drag_data.Read(OSExchangeData(CloneProvider(data))));
EXPECT_TRUE(drag_data.is_valid());
ASSERT_EQ(1, drag_data.elements.size());
@@ -69,7 +69,7 @@ TEST_F(BookmarkDragDataTest, JustURL) {
EXPECT_EQ(0, drag_data.elements[0].children.size());
}
-TEST_F(BookmarkDragDataTest, URL) {
+TEST_F(BookmarkNodeDataTest, URL) {
// Write a single node representing a URL to the clipboard.
TestingProfile profile;
profile.CreateBookmarkModel(false);
@@ -80,7 +80,7 @@ TEST_F(BookmarkDragDataTest, URL) {
GURL url(GURL("http://foo.com"));
const string16 title(ASCIIToUTF16("blah"));
const BookmarkNode* node = model->AddURL(root, 0, title, url);
- BookmarkDragData drag_data(node);
+ BookmarkNodeData drag_data(node);
EXPECT_TRUE(drag_data.is_valid());
ASSERT_EQ(1, drag_data.elements.size());
EXPECT_TRUE(drag_data.elements[0].is_url);
@@ -91,7 +91,7 @@ TEST_F(BookmarkDragDataTest, URL) {
// Now read the data back in.
OSExchangeData data2(CloneProvider(data));
- BookmarkDragData read_data;
+ BookmarkNodeData read_data;
EXPECT_TRUE(read_data.Read(data2));
EXPECT_TRUE(read_data.is_valid());
ASSERT_EQ(1, read_data.elements.size());
@@ -113,7 +113,7 @@ TEST_F(BookmarkDragDataTest, URL) {
}
// Tests writing a group to the clipboard.
-TEST_F(BookmarkDragDataTest, Group) {
+TEST_F(BookmarkNodeDataTest, Group) {
TestingProfile profile;
profile.CreateBookmarkModel(false);
profile.BlockUntilBookmarkModelLoaded();
@@ -124,7 +124,7 @@ TEST_F(BookmarkDragDataTest, Group) {
const BookmarkNode* g11 = model->AddGroup(g1, 0, ASCIIToUTF16("g11"));
const BookmarkNode* g12 = model->AddGroup(g1, 0, ASCIIToUTF16("g12"));
- BookmarkDragData drag_data(g12);
+ BookmarkNodeData drag_data(g12);
EXPECT_TRUE(drag_data.is_valid());
ASSERT_EQ(1, drag_data.elements.size());
EXPECT_EQ(g12->GetTitle(), WideToUTF16Hack(drag_data.elements[0].title));
@@ -135,7 +135,7 @@ TEST_F(BookmarkDragDataTest, Group) {
// Now read the data back in.
OSExchangeData data2(CloneProvider(data));
- BookmarkDragData read_data;
+ BookmarkNodeData read_data;
EXPECT_TRUE(read_data.Read(data2));
EXPECT_TRUE(read_data.is_valid());
ASSERT_EQ(1, read_data.elements.size());
@@ -152,7 +152,7 @@ TEST_F(BookmarkDragDataTest, Group) {
}
// Tests reading/writing a folder with children.
-TEST_F(BookmarkDragDataTest, GroupWithChild) {
+TEST_F(BookmarkNodeDataTest, GroupWithChild) {
TestingProfile profile;
profile.SetID(L"id");
profile.CreateBookmarkModel(false);
@@ -166,18 +166,18 @@ TEST_F(BookmarkDragDataTest, GroupWithChild) {
model->AddURL(group, 0, title, url);
- BookmarkDragData drag_data(group);
+ BookmarkNodeData drag_data(group);
OSExchangeData data;
drag_data.Write(&profile, &data);
// Now read the data back in.
OSExchangeData data2(CloneProvider(data));
- BookmarkDragData read_data;
+ BookmarkNodeData read_data;
EXPECT_TRUE(read_data.Read(data2));
ASSERT_EQ(1, read_data.elements.size());
ASSERT_EQ(1, read_data.elements[0].children.size());
- const BookmarkDragData::Element& read_child =
+ const BookmarkNodeData::Element& read_child =
read_data.elements[0].children[0];
EXPECT_TRUE(read_child.is_url);
@@ -191,7 +191,7 @@ TEST_F(BookmarkDragDataTest, GroupWithChild) {
}
// Tests reading/writing of multiple nodes.
-TEST_F(BookmarkDragDataTest, MultipleNodes) {
+TEST_F(BookmarkNodeDataTest, MultipleNodes) {
TestingProfile profile;
profile.SetID(L"id");
profile.CreateBookmarkModel(false);
@@ -209,24 +209,24 @@ TEST_F(BookmarkDragDataTest, MultipleNodes) {
std::vector<const BookmarkNode*> nodes;
nodes.push_back(group);
nodes.push_back(url_node);
- BookmarkDragData drag_data(nodes);
+ BookmarkNodeData drag_data(nodes);
OSExchangeData data;
drag_data.Write(&profile, &data);
// Read the data back in.
OSExchangeData data2(CloneProvider(data));
- BookmarkDragData read_data;
+ BookmarkNodeData read_data;
EXPECT_TRUE(read_data.Read(data2));
EXPECT_TRUE(read_data.is_valid());
ASSERT_EQ(2, read_data.elements.size());
ASSERT_EQ(1, read_data.elements[0].children.size());
- const BookmarkDragData::Element& read_group = read_data.elements[0];
+ const BookmarkNodeData::Element& read_group = read_data.elements[0];
EXPECT_FALSE(read_group.is_url);
EXPECT_EQ(L"g1", read_group.title);
EXPECT_EQ(1, read_group.children.size());
- const BookmarkDragData::Element& read_url = read_data.elements[1];
+ const BookmarkNodeData::Element& read_url = read_data.elements[1];
EXPECT_TRUE(read_url.is_url);
EXPECT_EQ(title, WideToUTF16Hack(read_url.title));
EXPECT_EQ(0, read_url.children.size());
@@ -36,30 +36,30 @@ OSExchangeData::Provider* CloneProvider(const OSExchangeData& data) {
EXPECT_FALSE(drag_data.is_valid());
}
-// Writes a URL to the clipboard and make sure BookmarkDragData can correctly
+// Writes a URL to the clipboard and make sure BookmarkNodeData can correctly
// read it.